package com.ruoyi.system.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.system.domain.ActClassification;
import org.springframework.stereotype.Repository;

/**
 * 分配信息Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-11
 */
@Repository
public interface ActClassificationMapper 
{
    /**
     * 查询分配信息
     * 
     * @param id 分配信息ID
     * @return 分配信息
     */
    public ActClassification selectActClassificationById(Long id);

    /**
     * 查询分配信息列表
     * 
     * @param actClassification 分配信息
     * @return 分配信息集合
     */
    public List<ActClassification> selectActClassificationList(ActClassification actClassification);

    /**
     * 新增分配信息
     * 
     * @param actClassification 分配信息
     * @return 结果
     */
    public int insertActClassification(ActClassification actClassification);

    /**
     * 修改分配信息
     * 
     * @param actClassification 分配信息
     * @return 结果
     */
    public int updateActClassification(ActClassification actClassification);

    /**
     * 删除分配信息
     * 
     * @param id 分配信息ID
     * @return 结果
     */
    public int deleteActClassificationById(Long id);

    /**
     * 批量删除分配信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteActClassificationByIds(Long[] ids);

    List<Integer> findId(Long id);

    int updateActClassification(Map<String, Object> paramMap);
    int setEnable(Map<String, Object> paramMap);
    int setDisable(Map<String, Object> paramMap);

    List<ActClassification> selectAll();
    List<ActClassification> selectByParentId(int parentId);

    List<ActClassification> savePid(Long sskId);

    List<ActClassification> selectSubActDy(int sskId);
}
